@@ -32,7 +32,7 @@ QTEST_MAIN(AddressTest)
 #ifndef Q_OS_WIN
 void initLocale()
 {
-    qputenv("LC_ALL", "en_US.utf-8");
+    qputenv("LC_ALL", "it_CH.utf-8");
 }
 
 Q_CONSTRUCTOR_FUNCTION(initLocale)
@@ -162,27 +162,12 @@ void AddressTest::formatTest()
 {
     {
         // check availability of country to ISO code mapping data file
-        const QString mapfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kcontacts/countrytransl.map"));
-        QVERIFY2(!mapfile.isEmpty(), "Country to ISO code mapping data file does not exist");
-
-        QFileInfo fileInfo(mapfile);
+        QFileInfo fileInfo(QStringLiteral(":/org.kde.kcontacts/countrytransl.map"));
         QVERIFY2(fileInfo.exists(), "Country to ISO code mapping data file does not exist");
         QVERIFY2(fileInfo.isReadable(), "Country to ISO code mapping data file is not readable");
     }
 
     {
-        const QString templateFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/locale/countries/de/country.desktop"));
-        QVERIFY(!templateFile.isEmpty());
-        const KConfig templateConfig(templateFile);
-        QVERIFY2(templateConfig.hasGroup("KCM Locale"),
-                 "Address format config for 'de' is missing expected 'KCM Locale' group");
-        const KConfigGroup templateGroup = templateConfig.group("KCM Locale");
-        QVERIFY2(templateGroup.hasKey("AddressFormat"),
-                 "Address format config is missing expected key 'AddressFormat'");
-        const QString addressTemplate = templateGroup.readEntry("AddressFormat");
-        QVERIFY2(!addressTemplate.isEmpty(),
-                 "Address format template for 'de' is empty");
-
         KContacts::Address address;
         address.setStreet(QStringLiteral("Lummerlandstr. 1"));
         address.setPostalCode(QStringLiteral("12345"));
@@ -229,10 +214,24 @@ void AddressTest::formatTest()
         address.setLocality(QStringLiteral("Lummerstadt"));
         address.setCountry(QString());
 
-        const QString result(QStringLiteral("Jim Knopf\nLummerlandstr. 1\nLummerstadt, 12345"));
+        const QString result(QStringLiteral("Jim Knopf\nLummerlandstr. 1\n12345 Lummerstadt"));
 
         QCOMPARE(address.formattedAddress(QStringLiteral("Jim Knopf")), result);
     }
+
+    {
+        KContacts::Address address;
+        address.setStreet(QStringLiteral("Haus Randa"));
+        address.setPostalCode(QStringLiteral("1234"));
+        address.setLocality(QStringLiteral("Randa"));
+        address.setPostOfficeBox(QStringLiteral("5678"));
+        address.setCountry(QStringLiteral("Schweiz"));
+
+        // we want the Italian variant of the Swiss format for it_CH
+        const QString result(QStringLiteral("Dr. Konqui\nCasella postale 5678\nHaus Randa\n1234 Randa\n\nSCHWEIZ"));
+
+        QCOMPARE(address.formattedAddress(QStringLiteral("Dr. Konqui")), result);
+    }
 }
 
 void AddressTest::shouldExportVcard3()
@@ -426,3 +425,13 @@ void AddressTest::shouldExportVcard4()
                         "END:VCARD\r\n\r\n");
     QCOMPARE(ba, expected);
 }
+
+void AddressTest::countryToISOTest()
+{
+    using namespace KContacts;
+    QCOMPARE(Address::countryToISO(QStringLiteral("France")), QLatin1String("fr"));
+    QCOMPARE(Address::countryToISO(QStringLiteral("Frankreich")), QLatin1String("fr"));
+    QCOMPARE(Address::countryToISO(QStringLiteral("Germany")), QLatin1String("de"));
+    QCOMPARE(Address::countryToISO(QStringLiteral("Österreich")), QLatin1String("at"));
+    QCOMPARE(Address::countryToISO(QStringLiteral("Disneyland")), QString());
+}
