@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (c) 2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -27,7 +27,7 @@ class TitleTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit TitleTest(QObject *parent = Q_NULLPTR);
+    explicit TitleTest(QObject *parent = nullptr);
     ~TitleTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
