@@ -576,6 +576,16 @@ QString Address::toString() const
     return str;
 }
 
+static QString countryCodeFromLocale()
+{
+    const auto n = QLocale().name(); // this is in the form <lang>_<COUNTRY>, with the exception of 'C'
+    const auto idx = n.indexOf(QLatin1Char('_'));
+    if (idx > 0) {
+        return n.mid(idx + 1).toLower();
+    }
+    return {};
+}
+
 QString Address::formattedAddress(const QString &realName, const QString &orgaName) const
 {
     QString ciso;
@@ -587,11 +597,11 @@ QString Address::formattedAddress(const QString &realName, const QString &orgaNa
         ciso = countryToISO(country());
     } else {
         // fall back to our own country
-        ciso = QLocale().bcp47Name();
+        ciso = countryCodeFromLocale();
     }
-    KConfig entry(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kf5/locale/countries/") + ciso + QLatin1String("/country.desktop")));
+    static KConfig entry(QStringLiteral(":/org.kde.kcontacts/addressformatrc"));
 
-    KConfigGroup group = entry.group("KCM Locale");
+    KConfigGroup group = entry.group(ciso);
     // decide whether this needs special business address formatting
     if (orgaName.isEmpty()) {
         addrTemplate = group.readEntry("AddressFormat");
@@ -617,10 +627,7 @@ QString Address::formattedAddress(const QString &realName, const QString &orgaNa
     // now add the country line if needed (formatting this time according to
     // the rules of our own system country )
     if (!country().isEmpty()) {
-        KConfig entry(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kf5/locale/countries/")
-                                             +QLocale().name()
-                                             +QLatin1String("/country.desktop")));
-        KConfigGroup group = entry.group("KCM Locale");
+        KConfigGroup group = entry.group(countryCodeFromLocale());
         QString cpos = group.readEntry("AddressCountryPosition");
         if (QLatin1String("BELOW") == cpos || cpos.isEmpty()) {
             ret = ret + QLatin1String("\n\n") + country().toUpper();
@@ -636,67 +643,69 @@ QString Address::formattedAddress(const QString &realName, const QString &orgaNa
     return ret;
 }
 
-typedef QMap<QString, QString> StringMap;
-Q_GLOBAL_STATIC(StringMap, sISOMap)
+struct IsoCache {
+    QHash<QString, QString> countryToIso;
+    QHash<QString, QString> isoToCountry;
+};
+Q_GLOBAL_STATIC(IsoCache, sIsoCache)
 
 QString Address::countryToISO(const QString &cname)
 {
     // we search a map file for translations from country names to
-    // iso codes, storing caching things in a QMap for faster future
+    // iso codes, storing caching things in a QHash for faster future
     // access.
 
-    QMap<QString, QString>::ConstIterator it;
-    it = sISOMap->constFind(cname);
-    if (it != sISOMap->constEnd()) {
+    const auto it = sIsoCache->countryToIso.constFind(cname);
+    if (it != sIsoCache->countryToIso.constEnd()) {
         return it.value();
     }
 
-    QString mapfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kcontacts/countrytransl.map"));
-    if (mapfile.isEmpty()) {
-        qWarning() << "Installation error, couldn't find the countrytransl.map file";
-    }
-
-    QFile file(mapfile);
+    QFile file(QStringLiteral(":/org.kde.kcontacts/countrytransl.map"));
     if (file.open(QIODevice::ReadOnly)) {
         QTextStream s(&file);
         QString strbuf = s.readLine();
         while (!strbuf.isEmpty()) {
-            QStringList countryInfo = strbuf.split(QLatin1Char('\t'), QString::KeepEmptyParts);
+            const auto countryInfo = strbuf.splitRef(QLatin1Char('\t'), QString::KeepEmptyParts);
             if (countryInfo[0] == cname) {
                 file.close();
-                sISOMap->insert(cname, countryInfo[1]);
-                return countryInfo[1];
+                const auto iso = countryInfo[1].toString();
+                sIsoCache->countryToIso.insert(cname, iso);
+                return iso;
             }
             strbuf = s.readLine();
         }
         file.close();
     }
 
-    // fall back to system country
-    QString systemCountry = QLocale().bcp47Name();
-    sISOMap->insert(cname, systemCountry);
-    return systemCountry;
+    return {};
 }
 
 QString Address::ISOtoCountry(const QString &ISOname)
 {
     // get country name from ISO country code (e.g. "no" -> i18n("Norway"))
-    if (ISOname.simplified().isEmpty()) {
+    const auto iso = ISOname.simplified().toLower();
+    if (iso.simplified().isEmpty()) {
         return QString();
     }
 
-    QString mapfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/kcontacts/countrytransl.map"));
+    const auto it = sIsoCache->isoToCountry.constFind(iso);
+    if (it != sIsoCache->isoToCountry.constEnd()) {
+        return it.value();
+    }
 
-    QFile file(mapfile);
+    QFile file(QStringLiteral(":/org.kde.kcontacts/countrytransl.map"));
     if (file.open(QIODevice::ReadOnly)) {
         QTextStream s(&file);
-        QString searchStr = QLatin1Char('\t') + ISOname.simplified().toLower();
+        QString searchStr = QLatin1Char('\t') + iso;
         QString strbuf = s.readLine();
         while (!strbuf.isEmpty()) {
             int pos;
             if ((pos = strbuf.indexOf(searchStr)) != -1) {
                 file.close();
-                return i18n(strbuf.left(pos).toUtf8().constData());
+                const auto country = i18n(strbuf.leftRef(pos).toUtf8().constData());
+                sIsoCache->isoToCountry.insert(iso, country);
+                sIsoCache->countryToIso.insert(country, iso);
+                return country;
             }
             strbuf = s.readLine();
         }
