@@ -1,6 +1,6 @@
 /*
     This file is part of the KContacts framework.
-    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -29,8 +29,7 @@
 /** @short Class that holds a Title for a contact.
  *  @since 5.3
  */
-namespace KContacts
-{
+namespace KContacts {
 class KCONTACTS_EXPORT Title
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Title &);
@@ -45,19 +44,19 @@ public:
     typedef QVector<Title> List;
 
     void setTitle(const QString &title);
-    QString title() const;
+    Q_REQUIRED_RESULT QString title() const;
 
-    bool isValid() const;
+    Q_REQUIRED_RESULT bool isValid() const;
 
     void setParameters(const QMap<QString, QStringList> &params);
-    QMap<QString, QStringList> parameters() const;
+    Q_REQUIRED_RESULT QMap<QString, QStringList> parameters() const;
 
-    bool operator==(const Title &other) const;
-    bool operator!=(const Title &other) const;
+    Q_REQUIRED_RESULT bool operator==(const Title &other) const;
+    Q_REQUIRED_RESULT bool operator!=(const Title &other) const;
 
     Title &operator=(const Title &other);
 
-    QString toString() const;
+    Q_REQUIRED_RESULT QString toString() const;
 private:
     class Private;
     QSharedDataPointer<Private> d;
@@ -65,7 +64,6 @@ private:
 KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Title &object);
 
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Title &object);
-
 }
 Q_DECLARE_TYPEINFO(KContacts::Title, Q_MOVABLE_TYPE);
 #endif // TITLE_H
